package com.example.tmap_test

import android.os.Build
import android.os.Bundle
import android.util.Log
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.annotation.RequiresApi
import androidx.fragment.app.Fragment
import androidx.recyclerview.widget.LinearLayoutManager
import com.example.tmap_test.databinding.CapyListFragmentBinding

class CapyListFragment : Fragment() {
    companion object {
        private val TAG = CapyListFragment::class.java.simpleName
    }

    private lateinit var binding: CapyListFragmentBinding
    private lateinit var myAdapter: RecyclerAdapter

    private val images = listOf(R.drawable.image1, R.drawable.image2, R.drawable.image3)
    private val data = mutableListOf<ListItem>()

    init {
        for (i in 1..5) {
            data.add(ListItem("Item $i", images[i % 3]))
        }
    }

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        binding = CapyListFragmentBinding.inflate(inflater, container, false)
        return binding.root
    }

    @RequiresApi(Build.VERSION_CODES.TIRAMISU)
    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        val initData = requireArguments().getInt("data")

        Log.i(TAG, "Init data passed: $initData")

        myAdapter = RecyclerAdapter(requireContext(), data)
        setUpRecycler()

        binding.btnAdd.setOnClickListener {
            addItem()
        }
    }

    private fun setUpRecycler() {
        binding.rv.apply {
            adapter = myAdapter
            layoutManager = LinearLayoutManager(requireContext())
            setHasFixedSize(true)
        }
    }

    private fun addItem() {
        val newItem = ListItem("Item ${data.size + 1}", R.drawable.image1)
        Log.i(TAG, "Item added: $newItem")
        data.add(newItem)
        myAdapter.notifyItemInserted(data.size - 1)
        binding.rv.scrollToPosition(data.size - 1)
    }
}